//GeoGet 2

function ExportExtension: string;
begin
  result := 'GPX';
end;

function ExportDescription: string;
begin
  result := 'GeoTrip GPX';
end;

function ExportHint: string;
begin
  result := 'Basic exchange format for Geoget. All in one file. (Include Geoget specific data.)';
  if copy(GetCurrentLanguage, 1, 2) = 'cs' then
    result := 'Zkladn vmnn formt pro Geoget. Ve do jednoho souboru. (Vetn specifickch dat Geogetu.)';
end;

function ExportHeader: string;
begin
  Result := '<?xml version="1.0" encoding="utf-8" standalone="no"?>' + CRLF;
  Result := Result + '<gpx xmlns="http://www.topografix.com/GPX/1/1"'
    + ' creator="' + Geoget_Version + '" version="1.1"'
    + ' xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"'
    + ' xmlns:gpxx="http://www.garmin.com/xmlschemas/GpxExtensions/v3"'
    + ' xsi:schemaLocation="'
    + 'http://geoget.ararat.cz/GpxExtensions/v2 http://geoget.ararat.cz/GpxExtensions/v2/geoget.xsd' 
    + ' http://www.groundspeak.com/cache/1/0 http://www.groundspeak.com/cache/1/0/cache.xsd'
    + ' http://www.topografix.com/GPX/1/1 http://www.topografix.com/GPX/1/1/gpx.xsd'
    + ' http://www.garmin.com/xmlschemas/GpxExtensions/v3 http://www8.garmin.com/xmlschemas/GpxExtensionsv3.xsd'
    + '">' + CRLF;
  Result := Result + ' <metadata>' + CRLF;
  Result := Result + '   <desc>Geoget data file</desc>' + CRLF;
  Result := Result + '   <time>' + formatdatetime('yyyy"-"mm"-"dd"T"hh":"nn":"ss"."zzz', now) + '</time>' + CRLF;
  Result := Result + ' </metadata>' + CRLF;
  Result := Result + CRLF;

  Result := Result + ' <extensions>' + CRLF;
  Result := Result + '   <ref lat="' +  GEOGET_REFX + '" lon="' + GEOGET_REFY + '">' + CRLF;
  Result := Result + '     <name>' + cdata(GEOGET_REFNAME) + '</name>' + CRLF;
  Result := Result + '   </ref>' + CRLF;
  Result := Result + ' </extensions>' + CRLF;
  Result := Result + CRLF;
end;

function ExportFooter: string;
begin
  result := '</gpx>' + CRLF;
end;

function ExportPoint: string;
var
  s: string;
  n, m: integer;
  l: TStringlist;
  lv: TStringlist;
begin
  Result := '';
  //Export for Geocaches
  if GC.IsListed then
  begin
    Result := Result + ' <wpt lat="' + GC.Lat + '" lon="' + GC.Lon + '">' + CRLF;
    Result := Result + '  <time>'
      + formatdatetime('yyyy"-"mm"-"dd"T"hh":"nn":"ss"."zzz', GC.Hidden) + '</time>' + CRLF;
    Result := Result + '  <name>' + GC.ID +'</name>' + CRLF;
    Result := Result + '  <desc>' + cdata(GC.Name + ' by ' + GC.Author
          + ' (' + GC.Difficulty + '/' + GC.Terrain + ')') +'</desc>' + CRLF;
    Result := Result + '  <link href="'+GC.URL+'">' + CRLF;
    Result := Result + '    <text>' + cdata(GC.Name + ' by ' + GC.Author) + '</text>' + CRLF;
    Result := Result + '  </link>' + CRLF;
    if GC.IsFound then
      Result := Result + '  <sym>Geocache Found</sym>' + CRLF
    else
      Result := Result + '  <sym>Geocache</sym>' + CRLF;
    Result := Result + '  <type>Geocache|' + GC.CacheType + '</type>' + CRLF;
    Result := Result + '  <extensions>' + CRLF;
    if GC.IsDisabled then
      s := 'available="False"'
    else
      s := 'available="True"';
    if GC.IsArchived then
      s := s + ' archived="True"'
    else
      s := s + ' archived="False"';
    s := 'id="' + GC.CacheID +'" ' + s;
    Result := Result + '   <groundspeak:cache ' + s + ' xmlns:groundspeak="http://www.groundspeak.com/cache/1/0">' + CRLF;
    Result := Result + '    <groundspeak:name>' + cdata(GC.Name) + '</groundspeak:name>' + CRLF;
    Result := Result + '    <groundspeak:placed_by>' + cdata(GC.Author) +'</groundspeak:placed_by>' + CRLF;
    if GC.OwnerID <> '' then
    Result := Result + '    <groundspeak:owner id="' + GC.OwnerID + '">' + cdata(GC.Author) +'</groundspeak:owner>' + CRLF;
    Result := Result + '    <groundspeak:type>' + GC.CacheType +'</groundspeak:type>' + CRLF;
    Result := Result + '    <groundspeak:container>' + GC.Size +'</groundspeak:container>' + CRLF;
    Result := Result + '    <groundspeak:difficulty>' + GC.Difficulty +'</groundspeak:difficulty>' + CRLF;
    Result := Result + '    <groundspeak:terrain>' + GC.Terrain +'</groundspeak:terrain>' + CRLF;
    Result := Result + '    <groundspeak:country>' + GC.Country +'</groundspeak:country>' + CRLF;
    Result := Result + '    <groundspeak:state>' + GC.State +'</groundspeak:state>' + CRLF;
    Result := Result + '    <groundspeak:short_description html="True">' + cdata(GC.ShortDescription) +'</groundspeak:short_description>' + CRLF;
    Result := Result + '   </groundspeak:cache>' + CRLF;
    Result := Result + '   <gpxg:GeogetExtension xmlns:gpxg="http://geoget.ararat.cz/GpxExtensions/v2">' + CRLF;
    s := GC.TagCategories;
    if s <> '' then
    begin
      Result := Result + '     <gpxg:Tags>' + CRLF;
      l := TStringlist.create;
      lv := TStringlist.create;
      try
        l.text := s;
        for n := 0 to l.count - 1 do
        begin
          s := GC.TagValues(l[n]);
          lv.text := s;
          for m := 0 to lv.count - 1 do
            Result := Result + '       <gpxg:Tag Category="'+l[n]+'">'+cdata(lv[m]) + '</gpxg:Tag>' + CRLF;
        end;
      finally
        lv.free;
        l.free;
      end;
      Result := Result + '     </gpxg:Tags>' + CRLF;
    end;
    Result := Result + '   </gpxg:GeogetExtension>' + CRLF;
    Result := Result + '  </extensions>' + CRLF;
    Result := Result + ' </wpt>' + CRLF + CRLF;
  end;
end;
